@@ -5,7 +5,7 @@ import pytest
 from stringenum import DuplicateFreeStrEnum
 
 
-def test_duplicate_value_raises_error():
+def test_duplicate_value_raises_error() -> None:
     with pytest.raises(ValueError, match="Duplicate values are not allowed in Color"):
 
         class ColorWithDuplicateValue(DuplicateFreeStrEnum):
@@ -14,7 +14,7 @@ def test_duplicate_value_raises_error():
             BLUE = "Red"  # This should raise an error because "Red" == "red" (case-insensitive)
 
 
-def test_duplicate_name_raises_error():
+def test_duplicate_name_raises_error() -> None:
     with pytest.raises(ValueError, match="Duplicate names are not allowed in Color"):
 
         class ColorWithDuplicateName(DuplicateFreeStrEnum):
